@@ -9,6 +9,7 @@
 #include <private/qqmlcomponent_p.h>
 #include <private/qqmlpropertyresolver_p.h>
 #include <private/qqmlcomponentandaliasresolver_p.h>
+#include <private/qqmlsignalnames_p.h>
 
 #define COMPILE_EXCEPTION(token, desc) \
     { \
@@ -259,9 +260,9 @@ void QQmlTypeCompiler::addImport(const QString &module, const QString &qualifier
     document->imports.append(import);
 }
 
-CompositeMetaTypeIds QQmlTypeCompiler::typeIdsForComponent(int objectId) const
+QQmlType QQmlTypeCompiler::qmlTypeForComponent(const QString &inlineComponentName) const
 {
-    return typeData->typeIds(objectId);
+    return typeData->qmlType(inlineComponentName);
 }
 
 QQmlCompilePass::QQmlCompilePass(QQmlTypeCompiler *typeCompiler)
@@ -325,18 +326,21 @@ bool SignalHandlerResolver::resolveSignalHandlerExpressions(
             continue;
         }
 
-        if (!QmlIR::IRBuilder::isSignalPropertyName(bindingPropertyName))
+        QString qPropertyName;
+        QString signalName;
+        if (auto propertyName =
+                    QQmlSignalNames::changedHandlerNameToPropertyName(bindingPropertyName)) {
+            qPropertyName = *propertyName;
+            signalName = *QQmlSignalNames::changedHandlerNameToSignalName(bindingPropertyName);
+        } else {
+            signalName = QQmlSignalNames::handlerNameToSignalName(bindingPropertyName)
+                                 .value_or(QString());
+        }
+        if (signalName.isEmpty())
             continue;
 
         QQmlPropertyResolver resolver(propertyCache);
 
-        const QString signalName = QmlIR::IRBuilder::signalNameFromSignalPropertyName(
-                    bindingPropertyName);
-
-        QString qPropertyName;
-        if (signalName.endsWith(QLatin1String("Changed")))
-            qPropertyName = signalName.mid(0, signalName.size() - static_cast<int>(strlen("Changed")));
-
         bool notInRevision = false;
         const QQmlPropertyData * const signal = resolver.signal(signalName, &notInRevision);
         const QQmlPropertyData * const signalPropertyData = resolver.property(signalName, /*notInRevision ptr*/nullptr);
@@ -1047,7 +1051,7 @@ bool QQmlDeferredAndCustomParserBindingScanner::scanObject(
                     obj->flags |= Object::HasCustomParserBindings;
                     continue;
                 }
-            } else if (QmlIR::IRBuilder::isSignalPropertyName(name)
+            } else if (QQmlSignalNames::isHandlerName(name)
                        && !(customParser->flags() & QQmlCustomParser::AcceptsSignalHandlers)) {
                 obj->flags |= Object::HasCustomParserBindings;
                 binding->setFlag(Binding::IsCustomParserBinding);
